[![#](https://img.shields.io/pypi/pyversions/trackzero)](https://pypi.org/project/TrackZero/)
![#](https://img.shields.io/github/license/leiratech/TrackZero.Python?style=flat-square)

# TrackZero
Powerful, insightful and real-time BI Platfrom for developers to add to their platform.
It allows you to offer BI capabilities to your customers at affordable costs.
For more details on TrackZero, please visit [TrackZero website](https://trackzero.io).

# Documentation
For full documentation on this SDK, please check [the documentation](https://www.trackzero.io/docs).